@@ -1,8 +1,8 @@
 /* X-specific-EXT.h */
 
 
-extern int ask_me_yes_or_no (char *prompt);
-extern int ask_me_OK_or_cancel (char *prompt);
+extern int  ask_me_yes_or_no (char *prompt);
+extern int  ask_me_OK_or_cancel (char *prompt);
 extern void close_evalcall_form (void);
 extern void close_progress_form ();
 extern void fatal_error (char *error_string);
@@ -11,10 +11,10 @@ extern void mvaddstr_and_log_it (int y, int x, char *output);
 extern void open_evalcall_form (char *title);
 extern void open_progress_form (char *title, char *b1, char *b2, char *b3, long max_val);
 extern void log_file_end_to_screen (char *filename, char *grep_for_me);
-extern void log_to_screen (char *op);
+extern void log_to_screen (const char *op, ...);
 extern void popup_and_OK (char *prompt);
-extern bool popup_and_get_string (char *title, char *b, char *output);
-extern int popup_with_buttons (char *p, char *button1, char *button2);
+extern int  popup_and_get_string (char *title, char *b, char *output, int maxsize);
+extern int  popup_with_buttons (char *p, char *button1, char *button2);
 extern void refresh_log_screen ();
 extern void setup_newt_stuff ();
 extern void update_evalcall_form_ratio (int num, int denom);
