@@ -1,9 +1,8 @@
-/* libmondo-string.h */
+/*
+ * $Id: libmondo-string.h,v 1.2 2004/06/10 15:29:12 hugo Exp $
+ */
 
-
-
-
-char *build_partition_name (char *partition, char *drive, int partno);
+char *build_partition_name (char *partition, const char *drive, int partno);
 void center_string (char *in_out, int width);
 char *commarize(char*);
 char *disklist_entry_to_string (struct list_of_disks *disklist, int lino);
@@ -31,6 +30,5 @@ int compare_two_filelist_entries(void*va,void*vb);
 int severity_of_difference(char *filename, char *out_reason);
 
 char *percent_media_full_comment (struct s_bkpinfo *bkpinfo);
-
-
-
+char *media_descriptor_string(t_bkptype);
+inline void turn_wildcard_chars_into_literal_chars(char*out, char*in);
